@@ -442,7 +442,7 @@ class TestPresto(Validator):
         )
 
     @mock.patch("sqlglot.helper.logger")
-    def test_presto(self, mock_logger):
+    def test_presto(self, logger):
         self.validate_identity("SELECT * FROM x OFFSET 1 LIMIT 1")
         self.validate_identity("SELECT * FROM x OFFSET 1 FETCH FIRST 1 ROWS ONLY")
         self.validate_identity("SELECT BOOL_OR(a > 10) FROM asd AS T(a)")
