@@ -1,3 +1,5 @@
+from unittest import mock
+
 from tests.dialects.test_dialect import Validator
 
 
@@ -7,6 +9,10 @@ class TestSpark(Validator):
     def test_ddl(self):
         self.validate_identity("CREATE TABLE foo (col VARCHAR(50))")
         self.validate_identity("CREATE TABLE foo (col STRUCT<struct_col_a: VARCHAR((50))>)")
+        self.validate_identity("CREATE TABLE foo (col STRING) CLUSTERED BY (col) INTO 10 BUCKETS")
+        self.validate_identity(
+            "CREATE TABLE foo (col STRING) CLUSTERED BY (col) SORTED BY (col) INTO 10 BUCKETS"
+        )
 
         self.validate_all(
             "CREATE TABLE db.example_table (col_a struct<struct_col_a:int, struct_col_b:string>)",
@@ -144,7 +150,8 @@ TBLPROPERTIES (
             },
         )
 
-    def test_hint(self):
+    @mock.patch("sqlglot.generator.logger")
+    def test_hint(self, logger):
         self.validate_all(
             "SELECT /*+ COALESCE(3) */ * FROM x",
             write={
