@@ -227,12 +227,14 @@ class TestSchema(unittest.TestCase):
         self.assertEqual(schema.column_names(exp.Table(this="x")), ["foo"])
 
         # Check that the correct dialect is used when calling schema methods
+        # Note: T-SQL is case-insensitive by default, so `fo` in clickhouse will match the normalized table name
         schema = MappingSchema(schema={"[Fo]": {"x": "int"}}, dialect="tsql")
         self.assertEqual(
-            schema.column_names("[Fo]"), schema.column_names("`Fo`", dialect="clickhouse")
+            schema.column_names("[Fo]"), schema.column_names("`fo`", dialect="clickhouse")
         )
 
         # Check that all column identifiers are normalized to lowercase for BigQuery, even quoted
         # ones. Also, ensure that tables aren't normalized, since they're case-sensitive by default.
         schema = MappingSchema(schema={"Foo": {"`BaR`": "int"}}, dialect="bigquery")
         self.assertEqual(schema.column_names("Foo"), ["bar"])
+        self.assertEqual(schema.column_names("foo"), [])
