@@ -511,11 +511,11 @@ FROM v""",
         )
 
     @mock.patch("sqlglot.helper.logger")
-    def test_index_offset(self, mock_logger):
+    def test_index_offset(self, logger):
         self.validate("x[0]", "x[1]", write="presto", identity=False)
         self.validate("x[1]", "x[0]", read="presto", identity=False)
-        mock_logger.warning.assert_any_call("Applying array index offset (%s)", 1)
-        mock_logger.warning.assert_any_call("Applying array index offset (%s)", -1)
+        logger.warning.assert_any_call("Applying array index offset (%s)", 1)
+        logger.warning.assert_any_call("Applying array index offset (%s)", -1)
 
         self.validate("x[x - 1]", "x[x - 1]", write="presto", identity=False)
         self.validate(
